<?php

use Illuminate\Support\Facades\Route;

// 体测设备对接接口（API Key 认证）
Route::prefix('device')->middleware('api.key')->group(function () {
    Route::post('/inbody/sync', [\Kylin\Fitness\Http\Controllers\Device\InBodySyncController::class, 'sync']);
});
